/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * strcmp.h
 *
 * Code generation for function 'strcmp'
 *
 */

#ifndef STRCMP_H
#define STRCMP_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern boolean_T b_strcmp(const emxArray_char_T *a);
extern boolean_T c_strcmp(const emxArray_char_T *a);
extern boolean_T d_strcmp(const emxArray_char_T *a);
extern boolean_T e_strcmp(const emxArray_char_T *a);

#endif

/* End of code generation (strcmp.h) */
